@import url("themes/light/light.css");
@import url("themes/dark/dark.css");

/********************/
/* Start Button CSS */
button.dizmo-button {
    display: block;
    outline: none;
    font-size: 16px;
    font-family: "Pharma-Bold", sans-serif;
    font-weight: bold;
    text-transform: uppercase;
    background: none;
    border: none;
    width: 100px;
    height: 50px;
    padding: 0px;
    border-radius: 10px;
}
/* End Button CSS */
/******************/

/**********************/
/* Start checkbox CSS */
.dizmo-checkbox .dizmo-checkbox-input {
    display: none;
}

.dizmo-checkbox .dizmo-checkbox-label span.dizmo-checkbox-label-image {
    margin-right: 10px;
    width: 25px;
    height: 25px;
}

.dizmo-checkbox .dizmo-checkbox-label span {
    display: inline-block;
    vertical-align: middle;
}

.dizmo-checkbox .dizmo-checkbox-label {
    font-family: "Pharma-RegularCon";
    font-weight: normal;
    cursor: pointer;
    vertical-align: middle;
}
/* End Checkbox CSS */
/********************/

/******************************/
/* Start Custom Selectbox CSS */
.dizmo-selectbox {
    height: 48px;
    position: relative;
    border-radius: 10px;
    font-size: 16px;
}

.dizmo-selectbox-open {
    border-bottom-right-radius: 0px;
    border-bottom-left-radius: 0px;
}

.dizmo-selectbox span.dizmo-selectbox-text {
    line-height: 48px;
    text-indent: 10px;
    display: inline-block;
    font-family: "Pharma-Bold";
}

.dizmo-selectbox span.dizmo-selectbox-image {
    position: absolute;
    top: 20px;
    right: 10px;
    height: 15px;
    width: 15px;
}

.dizmo-selectbox ul.dizmo-selectbox-list {
    padding: 0px;
    margin: 0px;
    list-style-type: none;
    position: absolute;
    z-index: 1000;
    left: -1px;
    border-bottom-right-radius: 10px;
    border-bottom-left-radius: 10px;
}

.dizmo-selectbox ul.dizmo-selectbox-list li.dizmo-selectbox-list-entry {
    text-indent: 10px;
    padding-top: 10px;
    padding-bottom: 10px;
}

.dizmo-selectbox ul.dizmo-selectbox-list li.dizmo-selectbox-list-entry:first-child {
    margin-top: 10px;
}

.dizmo-selectbox ul.dizmo-selectbox-list li.dizmo-selectbox-list-entry:last-child {
    margin-bottom: 10px;
}
/* End Selectbox CSS*/
/********************/

/********************/
/* Start Slider CSS */
.dizmo-slider {
    padding: 25px;
    border-radius: 10px;
}

.dizmo-slider.orientation-horizontal {
    height: 2px;
}

.dizmo-slider.orientation-vertical {
    width: 2px;
}

.dizmo-slider .dizmo-slider-inner {
    background-image: none;
    background-repeat-x: initial;
    background-repeat-y: initial;
    background-attachment: initial;
    background-position-x: initial;
    background-position-y: initial;
    background-origin: initial;
    background-clip: initial;
    border: none;
    width: 100%;
    -apple-dashboard-region: dashboard-region(control rectangle);
}

.dizmo-slider .dizmo-slider-inner a.ui-slider-handle {
    border: none;
    width: 20px;
    height: 20px;
    outline: none;
    -apple-dashboard-region: dashboard-region(control rectangle);
}

.dizmo-slider.orientation-vertical .dizmo-slider-inner {
    width: 2px;
}

.dizmo-slider.orientation-vertical .dizmo-slider-inner a.ui-slider-handle {
    left: -9px;
}

.dizmo-slider.orientation-horizontal .dizmo-slider-inner {
    height: 2px;
}

.dizmo-slider.orientation-horizontal .dizmo-slider-inner a.ui-slider-handle {
    top: -9px;
}

/* End Slider CSS */
/******************/

/********************/
/* Start Switch CSS */
button.dizmo-switch {
    outline: none;
    border: none;
    padding: 0px;
    position: relative;
    border-radius: 10px;
}

button.dizmo-switch span.dizmo-switch-box {
    width: 50%;
    height: 100%;
    display: inline-block;
    position: absolute;
    top: -1px;
    background-repeat: no-repeat;
    border-radius: 10px;
}

button.dizmo-switch span.dizmo-switch-off-box {
    background-color: rgba(208, 64, 72, 1);
}

button.dizmo-switch span.dizmo-switch-on-box {
    background-color: rgb(175, 200, 25);
}

button.dizmo-switch-on span.dizmo-switch-on-box {
    -webkit-transition: left 0.5s, opacity 0.5s;
    left: 50%;
    opacity: 1;
}

button.dizmo-switch-on span.dizmo-switch-off-box {
    -webkit-transition: left 0.5s, opacity 0.5s;
    left: 50%;
    opacity: 0;
}

button.dizmo-switch-off span.dizmo-switch-on-box {
    -webkit-transition: left 0.5s, opacity 0.5s;
    left: 0%;
    opacity: 0;
}

button.dizmo-switch-off span.dizmo-switch-off-box {
    -webkit-transition: left 0.5s, opacity 0.5s;
    left: 0%;
    opacity: 1;
}
/* End Switch CSS */
/******************/
